@@ -3,7 +3,9 @@ from pickle import loads, dumps
 import numpy as np
 import pandas as pd
 
+from classicML import _cml_precision
 from classicML import CLASSICML_LOGGER
+from classicML.api.models import BaseModel
 from classicML.backend import type_of_target
 from classicML.backend import get_conditional_probability
 from classicML.backend import get_prior_probability
@@ -11,7 +13,7 @@ from classicML.backend import get_probability_density
 from classicML.backend import io
 
 
-class NaiveBayesClassifier(object):
+class NaiveBayesClassifier(BaseModel):
     """朴素贝叶斯分类器.
 
     Attributes:
@@ -55,7 +57,7 @@ class NaiveBayesClassifier(object):
         """
         self.smoothing = smoothing
 
-    def fit(self, x, y):
+    def fit(self, x, y, **kwargs):
         """训练朴素贝叶斯分类器.
 
         Arguments:
@@ -71,7 +73,7 @@ class NaiveBayesClassifier(object):
         # 为特征数据添加属性信息.
         x = pd.DataFrame(x, columns=self.attribute_name)
         x.reset_index(drop=True, inplace=True)
-        y = pd.Series(y)
+        y = pd.Series(y, dtype=_cml_precision.int)
         y.reset_index(drop=True, inplace=True)
 
         # 获取反正例的样本总数.
@@ -100,18 +102,20 @@ class NaiveBayesClassifier(object):
                 xi1_var = np.var(xi1)
 
                 self.pi_0.update({x.columns[attribute]: {
-                                  'continuous': continuous,
-                                  'values': [xi0_mean, xi0_var]}})  # values存放了均值和方差.
+                    'continuous': continuous,
+                    'values': [xi0_mean, xi0_var]}})  # values存放了均值和方差.
                 self.pi_1.update({x.columns[attribute]: {
-                                  'continuous': continuous,
-                                  'values': [xi1_mean, xi1_var]}})
+                    'continuous': continuous,
+                    'values': [xi1_mean, xi1_var]}})
             else:
                 # 离散值计算条件概率信息.
                 unique_value = xi.unique()
                 num_of_unique_value = len(unique_value)
 
-                xi0_value_count = pd.DataFrame(np.zeros((1, num_of_unique_value)), columns=unique_value)
-                xi1_value_count = pd.DataFrame(np.zeros((1, num_of_unique_value)), columns=unique_value)
+                xi0_value_count = pd.DataFrame(np.zeros([1, num_of_unique_value], dtype=_cml_precision.float),
+                                               columns=unique_value)
+                xi1_value_count = pd.DataFrame(np.zeros([1, num_of_unique_value], dtype=_cml_precision.float),
+                                               columns=unique_value)
 
                 for key in pd.value_counts(xi0).keys():
                     xi0_value_count[key] += pd.value_counts(xi0)[key]
@@ -139,7 +143,7 @@ class NaiveBayesClassifier(object):
 
         return self
 
-    def predict(self, x, probability=False):
+    def predict(self, x, probability=False, **kwargs):
         """使用朴素贝叶斯分类器进行预测.
 
         Arguments:
@@ -158,6 +162,18 @@ class NaiveBayesClassifier(object):
             CLASSICML_LOGGER.error('模型没有训练')
             raise ValueError('你必须先进行训练')
 
+        # 修正数据类型.
+        if isinstance(x, list):
+            x = np.expand_dims(x, axis=0)
+        elif isinstance(x, pd.Series):
+            x = np.expand_dims(x.values, axis=0)
+        elif isinstance(x, np.ndarray) and x.ndim == 1:
+            x = np.expand_dims(x, axis=0)
+
+        # 为特征数据添加属性信息.
+        x = pd.DataFrame(x, columns=self.attribute_name)
+        x.reset_index(drop=True, inplace=True)
+
         # 避免下溢进行对数处理.
         p_0 = np.log(self.p_0)
         p_1 = np.log(self.p_1)
@@ -170,7 +186,7 @@ class NaiveBayesClassifier(object):
                 x_test = x.iloc[i, :]
                 y_pred.append(self._predict(x_test, p_0, p_1, probability))
 
-        return y_pred
+        return np.asarray(y_pred)
 
     def _predict(self, x, p_0, p_1, probability):
         """通过朴素贝叶斯分类器预测单个样本.
@@ -194,22 +210,38 @@ class NaiveBayesClassifier(object):
                 mean0, var0 = pxi_0['values']
                 mean1, var1 = pxi_1['values']
 
-                p_0 += np.log(get_probability_density(x[index], mean0, var0))
-                p_1 += np.log(get_probability_density(x[index], mean1, var1))
+                p_0 += _cml_precision.float(np.log(get_probability_density(x[index], mean0, var0)))
+                p_1 += _cml_precision.float(np.log(get_probability_density(x[index], mean1, var1)))
             else:
                 D_c_x0, D_c0, N0 = pxi_0['values']
                 D_c_x1, D_c1, N1 = pxi_1['values']
 
-                p_0 += np.log(get_conditional_probability(D_c_x0[x[index]], D_c0, N0, self.smoothing))
-                p_1 += np.log(get_conditional_probability(D_c_x1[x[index]], D_c1, N1, self.smoothing))
+                p_0 += _cml_precision.float(
+                    np.log(get_conditional_probability(D_c_x0[x[index]], D_c0, N0, self.smoothing))
+                )
+                p_1 += _cml_precision.float(
+                    np.log(get_conditional_probability(D_c_x1[x[index]], D_c1, N1, self.smoothing))
+                )
 
         if probability:
             return [p_0 / (p_0 + p_1), p_1 / (p_0 + p_1)]
         else:
             if p_0 > p_1:
-                return 0
+                return _cml_precision.int(0)
             else:
-                return 1
+                return _cml_precision.int(1)
+
+    def score(self, x, y):
+        """在预测模式下计算准确率.
+
+        Arguments:
+            x: array-like, 特征数据.
+            y: array-like, 标签.
+
+        Returns:
+            当前的准确率.
+        """
+        return super(NaiveBayesClassifier, self).score(x, y)
 
     def load_weights(self, filepath):
         """加载模型参数.
@@ -272,4 +304,4 @@ class NaiveBayesClassifier(object):
             weights_ds.attrs['pi_1'] = np.void(dumps(self.pi_1))
         except TypeError:
             CLASSICML_LOGGER.error('模型权重保存失败, 请检查文件是否损坏')
-            raise TypeError('模型权重保存失败')
\ No newline at end of file
+            raise TypeError('模型权重保存失败')
